==> marray_1.30.0.zip: marray/doc/marrayClassesShort.R <==
###################################################
### chunk number 1: 
###################################################
#line 54 "marrayClassesShort.Rnw"
library(marray)
data(swirl)


###################################################
### chunk number 2: 
###################################################
#line 99 "marrayClassesShort.Rnw"
slotNames("marrayLayout")
slotNames(swirl)


###################################################
### chunk number 3: 
###################################################
#line 112 "marrayClassesShort.Rnw"
zebra.RG<-as.data.frame(cbind(c("swirl","WT","swirl","WT"), c("WT","swirl","WT","swirl"))) 
dimnames(zebra.RG)[[2]]<-c("Cy3","Cy5")
zebra.samples<-new("marrayInfo",
		    maLabels=paste("Swirl array ",1:4,sep=""), 
		    maInfo=zebra.RG,
		    maNotes="Description of targets for Swirl experiment")
zebra.samples


###################################################
### chunk number 4: 
###################################################
#line 135 "marrayClassesShort.Rnw"
L<-slot(swirl, "maLayout")
L@maNgr


###################################################
### chunk number 5:  eval=FALSE
###################################################
## #line 147 "marrayClassesShort.Rnw"
## showMethods(classes="marrayLayout")
## showMethods("summary",classes="marrayLayout") 


###################################################
### chunk number 6: 
###################################################
#line 160 "marrayClassesShort.Rnw"
showMethods("print")


###################################################
### chunk number 7: 
###################################################
#line 167 "marrayClassesShort.Rnw"
summary(swirl)


###################################################
### chunk number 8: 
###################################################
#line 182 "marrayClassesShort.Rnw"
swirl[1:100,2:3]


###################################################
### chunk number 9: 
###################################################
#line 211 "marrayClassesShort.Rnw"
swirl.layout<-maLayout(swirl)
maNspots(swirl)
maNspots(swirl.layout)
maNgr(swirl)
maNgc(swirl.layout)
maPrintTip(swirl[1:10,3])


###################################################
### chunk number 10: 
###################################################
#line 229 "marrayClassesShort.Rnw"
maNotes(swirl.layout)
maNotes(swirl.layout)<- "New value"
maNotes(swirl.layout)


###################################################
### chunk number 11: 
###################################################
#line 237 "marrayClassesShort.Rnw"
L<-new("marrayLayout")
L
maNgr(L)<-4


###################################################
### chunk number 12: 
###################################################
#line 254 "marrayClassesShort.Rnw"
swirl.norm<-as(swirl, "marrayNorm")    


###################################################
### chunk number 13: 
###################################################
#line 270 "marrayClassesShort.Rnw"
maPlate(swirl)<-maCompPlate(swirl,n=384)

==> marray_1.87.0.zip: marray/doc/marrayClassesShort.R <==
### R code from vignette source 'marrayClassesShort.Rnw'

###################################################
### code chunk number 1: marrayClassesShort.Rnw:53-55
###################################################
library(marray)
data(swirl)


###################################################
### code chunk number 2: marrayClassesShort.Rnw:98-100
###################################################
slotNames("marrayLayout")
slotNames(swirl)


###################################################
### code chunk number 3: marrayClassesShort.Rnw:111-118
###################################################
zebra.RG<-as.data.frame(cbind(c("swirl","WT","swirl","WT"), c("WT","swirl","WT","swirl"))) 
dimnames(zebra.RG)[[2]]<-c("Cy3","Cy5")
zebra.samples<-new("marrayInfo",
		    maLabels=paste("Swirl array ",1:4,sep=""), 
		    maInfo=zebra.RG,
		    maNotes="Description of targets for Swirl experiment")
zebra.samples


###################################################
### code chunk number 4: marrayClassesShort.Rnw:134-136
###################################################
L<-slot(swirl, "maLayout")
L@maNgr


###################################################
### code chunk number 5: marrayClassesShort.Rnw:146-148 (eval = FALSE)
###################################################
## showMethods(classes="marrayLayout")
## showMethods("summary",classes="marrayLayout") 


###################################################
### code chunk number 6: marrayClassesShort.Rnw:159-160
###################################################
showMethods("print")


###################################################
### code chunk number 7: marrayClassesShort.Rnw:166-167
###################################################
summary(swirl)


###################################################
### code chunk number 8: marrayClassesShort.Rnw:181-182
###################################################
swirl[1:100,2:3]


###################################################
### code chunk number 9: marrayClassesShort.Rnw:210-216
###################################################
swirl.layout<-maLayout(swirl)
maNspots(swirl)
maNspots(swirl.layout)
maNgr(swirl)
maNgc(swirl.layout)
maPrintTip(swirl[1:10,3])


###################################################
### code chunk number 10: marrayClassesShort.Rnw:228-231
###################################################
maNotes(swirl.layout)
maNotes(swirl.layout)<- "New value"
maNotes(swirl.layout)


###################################################
### code chunk number 11: marrayClassesShort.Rnw:236-239
###################################################
L<-new("marrayLayout")
L
maNgr(L)<-4


###################################################
### code chunk number 12: marrayClassesShort.Rnw:253-254
###################################################
swirl.norm<-as(swirl, "marrayNorm")    


###################################################
### code chunk number 13: marrayClassesShort.Rnw:269-270
###################################################
maPlate(swirl)<-maCompPlate(swirl,n=384)
